@@ -10,7 +10,7 @@ use Webqq::Client::Cache;
 use Webqq::Message::Queue;
 
 #定义模块的版本号
-our $VERSION = "7.2";
+our $VERSION = "7.4";
 
 use LWP::UserAgent;#同步HTTP请求客户端
 use Webqq::UserAgent;#异步HTTP请求客户端
@@ -44,6 +44,7 @@ use Webqq::Client::Method::_report;
 use Webqq::Client::Method::get_dwz;
 use Webqq::Client::Method::_get_offpic;
 use Webqq::Client::Method::_cookie_proxy;
+use Webqq::Client::Method::_relink;
 
 
 sub new {
@@ -94,6 +95,7 @@ sub new {
             group       =>  [],
             discuss     =>  [],
         },
+        is_first_login              =>  -1,
         cache_for_uin_to_qq         => Webqq::Client::Cache->new,
         cache_for_group_sig         => Webqq::Client::Cache->new,
         cache_for_stranger          => Webqq::Client::Cache->new,
@@ -124,6 +126,8 @@ sub new {
         je                          =>  undef,
         last_dispatch_time          =>  undef,
         send_interval               =>  3,
+        poll_failure_count_max      =>  3,
+        poll_failure_count          =>  0,
         
     };
     $self->{ua} = LWP::UserAgent->new(
@@ -154,9 +158,12 @@ sub new {
     }
     $self->{default_qq_param} =  dclone($self->{qq_param});
     $self->{default_qq_database} = dclone($self->{qq_database});
+
+    bless $self,$class;
+    $self->_prepare();
     #全局变量，方便其他包引用$self
     $Webqq::Client::_CLIENT = $self;
-    return bless $self;
+    return $self;
 }
 sub on_send_message :lvalue {
     my $self = shift;
@@ -210,6 +217,14 @@ sub on_input_img_verifycode :lvalue {
 sub login{
     my $self = shift;
     my %p = @_;
+      
+    if($self->{is_first_login} == -1){
+        $self->{is_first_login} = 1;
+    }     
+    elsif($self->{is_first_login} == 1){
+        $self->{is_first_login} = 0;
+    }
+
     @{$self->{default_qq_param}}{qw(qq pwd)} = @p{qw(qq pwd)};
     @{$self->{qq_param}}{qw(qq pwd)} = @p{qw(qq pwd)};
     console "QQ账号: $self->{default_qq_param}{qq} 密码: $self->{default_qq_param}{pwd}\n";
@@ -234,8 +249,7 @@ sub login{
                    $self->_report()
                 && $self->_check_sig() 
                 && $self->_get_vfwebqq()
-                && $self->_login2()
-                && $self->_cookie_proxy();
+                && $self->_login2();
                 last;
             }
             else{
@@ -263,7 +277,7 @@ sub login{
     #执行on_login回调
     if(ref $self->{on_login} eq 'CODE'){
         eval{
-            $self->{on_login}->($self);
+            $self->{on_login}->();
         };
         console $@ . "\n" if $@;
     }
@@ -279,7 +293,7 @@ sub relogin{
     #清空cookie
     $self->{cookie_jar} = HTTP::Cookies->new(hide_cookie2=>1);
     $self->{ua}->cookie_jar($self->{cookie_jar});
-    $self->{asyn_ua}->cookie_jar($self->{cookie_jar});
+    $self->{asyn_ua}->{cookie_jar} = $self->{cookie_jar};
     #重新设置初始化参数
     $self->{cache_for_uin_to_qq} = Webqq::Client::Cache->new;
     $self->{cache_for_group_sig} = Webqq::Client::Cache->new;
@@ -314,6 +328,7 @@ sub get_single_long_nick;
 sub _report;
 sub _cookie_proxy;
 sub _get_offpic;
+sub _relink;
 
 #接受一个消息，将它放到发送消息队列中
 sub send_message{
@@ -359,7 +374,7 @@ sub welcome{
     console "个性签名: " . ($w->{single_long_nick}?$w->{single_long_nick}:"（无）") . "\n"
 };
 sub logout;
-sub run {
+sub _prepare {
     my $self = shift;
     $self->_load_extra_accessor();
     #设置从接收消息队列中接收到消息后对应的处理函数
@@ -383,9 +398,9 @@ sub run {
         }
         
         #接收队列中接收到消息后，调用相关的消息处理回调，如果未设置回调，消息将丢弃
-        if(ref $self->on_receive_message eq 'CODE'){
+        if(ref $self->{on_receive_message} eq 'CODE'){
             eval{
-                $self->on_receive_message->($msg); 
+                $self->{on_receive_message}->($msg); 
             };
             console $@ . "\n" if $@;
         }
@@ -431,25 +446,30 @@ sub run {
         
     });
 
+};
 
-    console "开始接收消息\n";
-    $self->_recv_message();
-    console "客户端运行中...\n";
+sub run{
+    my $self = shift;
 
-    $self->{watchers}{timer_update_group_info} = AE::timer 600,600,sub{
+    $self->{watchers}{rand()} = AE::timer 600,600,sub{
         $self->update_group_info();
     };
 
+    console "开始接收消息\n";
+    $self->_recv_message();
+
     if(ref $self->{on_run} eq 'CODE'){
         eval{
-            $self->{on_run}->($self);
+            $self->{on_run}->();
         };
         console "$@\n" if $@;
     }
 
+
+    console "客户端运行中...\n";
     $self->{cv} = AE::cv;
     $self->{cv}->recv;
-};
+}
 sub search_cookie{
     my($self,$cookie) = @_;
     my $result = undef;
@@ -658,6 +678,7 @@ sub update_friends_info{
 sub update_group_info{
     my $self = shift;
     my $group = shift;
+    my $is_init = 1 if @{$self->{qq_database}{group}}  == 0;
     if(defined $group){
         for( @{$self->{qq_database}{group}} ){
             if($_->{ginfo}{code} eq $group->{ginfo}{code} ){
@@ -668,6 +689,12 @@ sub update_group_info{
             }
         } 
         push @{$self->{qq_database}{group}},$group;
+        if(!$is_init and ref $self->{on_new_group} eq 'CODE'){
+            eval {
+                $self->{on_new_group}->(dclone($group));
+            };
+            console $@ . "\n" if $@;
+        }
         return;
     }
     $self->update_group_list_info();
@@ -678,29 +705,24 @@ sub update_group_info{
             if(ref $group_info->{minfo} ne 'ARRAY'){
                 console "更新[ $gl->{name} ]成功，但暂时没有获取到群成员信息...\n";
             }
-            if( @{$self->{qq_database}{group}} > 0 ){
-                my $flag = 0;
-                for( @{$self->{qq_database}{group}} ){
-                    if($_->{ginfo}{code} eq $group_info->{ginfo}{code} ){
-                        $self->_detect_loss_group_member($_,$group_info);
-                        $self->_detect_new_group_member2($_,$group_info);
-                        $_ = $group_info if ref $group_info->{minfo} eq 'ARRAY';
-                        $flag = 1;
-                        last;
-                    }
-                }
-                if($flag == 0){
-                    push @{ $self->{qq_database}{group} }, $group_info ;
-                    if(ref $self->{on_new_group} eq 'CODE'){
-                        eval {
-                            $self->{on_new_group}->(dclone($group_info));
-                        };
-                        console $@ . "\n" if $@;
-                    }
+            my $flag = 0;
+            for( @{$self->{qq_database}{group}} ){
+                if($_->{ginfo}{code} eq $group_info->{ginfo}{code} ){
+                    $self->_detect_loss_group_member($_,$group_info);
+                    $self->_detect_new_group_member2($_,$group_info);
+                    $_ = $group_info if ref $group_info->{minfo} eq 'ARRAY';
+                    $flag = 1;
+                    last;
                 }
             }
-            else{
+            if($flag == 0){
                 push @{ $self->{qq_database}{group} }, $group_info;
+                if( !$is_init and ref $self->{on_new_group} eq 'CODE'){
+                    eval {
+                        $self->{on_new_group}->(dclone($group_info));
+                    };
+                    console $@ . "\n" if $@;
+                }
             }
         }
         else{console "更新[ $gl->{name} ]群信息失败\n";}
