@@ -5,7 +5,7 @@ sub Webqq::Client::_send_group_message{
     my($self,$msg) = @_;
     #将整个hash从UTF8还原回uincode编码
     my $msg_origin = dclone($msg);
-    $msg->{$_} = decode("utf8",$msg->{$_} ) for keys %$msg;
+    $msg->{$_} = decode("utf8",$msg->{$_} )  for grep {$_ ne 'raw_content'} keys %$msg;
     my $ua = $self->{asyn_ua};
 
     my $send_message_callback = $msg->{cb}||$self->{on_send_message};
