@@ -2,14 +2,14 @@ package Webqq::Message;
 use Webqq::Message::Face;
 use JSON;
 use Encode;
-use Webqq::Client::Util qw(console_stderr console);
+use Webqq::Client::Util qw(console);
 use Scalar::Util qw(blessed);
 sub reply_message{
     my $client = shift;
     my $msg = shift;
     my $content = shift;
     unless(blessed($msg)){
-        console_stderr "输入的msg数据非法\n";
+        console "输入的msg数据非法\n";
         return 0;
     }
     if($msg->{type} eq 'message'){
@@ -286,7 +286,7 @@ sub parse_send_status_msg{
     my ($json_txt) = @_;
     my $json     = undef;
     eval{$json = JSON->new->utf8->decode($json_txt)};
-    console_stderr "解析消息失败: $@ 对应的消息内容为: $json_txt\n" if $@ and $client->{debug};
+    console "解析消息失败: $@ 对应的消息内容为: $json_txt\n" if $@ and $client->{debug};
     if(ref $json eq 'HASH' and $json->{retcode}==0){
         return {is_success=>1,status=>"发送成功"}; 
     }
@@ -370,10 +370,11 @@ sub parse_receive_msg{
     my ($json_txt) = @_;  
     my $json     = undef;
     eval{$json = JSON->new->utf8->decode($json_txt)};
-    console_stderr "解析消息失败: $@ 对应的消息内容为: $json_txt\n" if $@ and $client->{debug};
+    console "解析消息失败: $@ 对应的消息内容为: $json_txt\n" if $@ and $client->{debug};
     if($json){
         #一个普通的消息
         if($json->{retcode}==0){
+            $client->{poll_failure_count} = 0;
             for my $m (@{ $json->{result} }){
                 #收到群临时消息
                 if($m->{poll_type} eq 'sess_message'){
@@ -430,7 +431,14 @@ sub parse_receive_msg{
                 }
                 #收到系统消息
                 elsif($m->{poll_type} eq 'sys_g_msg'){
-                    
+                    #my $msg = {
+                    #    type        =>  'sys_g_msg',
+                    #    msg_id      =>  $m->{value}{msg_id},
+                    #    from_uin    =>  $m->{value}{from_uin},
+                    #    to_uin      =>  $m->{value}{to_uin},
+                    #     
+                    #};
+                    #$client->msg_put($msg);
                 }
                 #收到强制下线消息
                 elsif($m->{poll_type} eq 'kick_message'){
@@ -449,21 +457,31 @@ sub parse_receive_msg{
             }
         }
         #可以忽略的消息，暂时不做任何处理
-        elsif($json->{retcode} == 102){}
+        elsif($json->{retcode} == 102 or $json->{retcode} == 109 or $json->{retcode} == 110 ){
+            $client->{poll_failure_count} = 0;
+        }
         #更新客户端ptwebqq值
         elsif($json->{retcode} == 116){$client->{qq_param}{ptwebqq} = $json->{p};}
         #未重新登录
-        elsif($json->{retcode} ==100 or $json->{retcode} ==103){
-            console_stderr "需要重新登录\n";
+        elsif($json->{retcode} ==100){
+            console "因网络或其他原因与服务器失去联系，客户端需要重新登录...\n";
             $client->relogin();
         }
         #重新连接失败
         elsif($json->{retcode} ==120 or $json->{retcode} ==121 ){
-            console_stderr "重新连接失败\n";
-            $client->relogin();
+            console "因网络或其他原因与服务器失去联系，客户端需要重新连接...\n";
+            $client->_relink();
         }
         #其他未知消息
-        else{console_stderr "读取到未知消息: $json_txt\n";}
+        else{
+            $client->{poll_failure_count}++;
+            console "获取消息失败，当前失败次数: $client->{poll_failure_count}\n";
+            if($client->{poll_failure_count} > $client->{poll_failure_count_max}){
+                console "接收消息失败次数超过最大值，尝试进行重新连接...\n";
+                $client->{poll_failure_count}   =  0;
+                $client->_relink();
+            }
+        }
     } 
 }
 1;
